@@ -2,20 +2,19 @@
 
 from __future__ import annotations
 
+import contextlib
 import os
 import sys
-from contextlib import suppress
 
-VIRTUALENV_PATCH_FILE = os.path.join(__file__)
+VIRTUALENV_PATCH_FILE = os.path.abspath(__file__)
 
 
 def patch_dist(dist):
-    """
-    Distutils allows user to configure some arguments via a configuration file:
-    https://docs.python.org/3/install/index.html#distutils-configuration-files.
+    """Distutils allows user to configure some arguments via a configuration file: https://docs.python.org/3/install/index.html#distutils-configuration-files.
 
     Some of this arguments though don't make sense in context of the virtual environment files, let's fix them up.
-    """  # noqa: D205
+
+    """
     # we cannot allow some install config as that would get packages installed outside of the virtual environment
     old_parse_config_files = dist.Distribution.parse_config_files
 
@@ -48,13 +47,20 @@ class _Finder:
     # lock[0] is threading.Lock(), but initialized lazily to avoid importing threading very early at startup,
     # because there are gevent-based applications that need to be first to import threading by themselves.
     # See https://github.com/pypa/virtualenv/issues/1895 for details.
-    lock = []
+    lock = []  # noqa: RUF012
 
     def find_spec(self, fullname, path, target=None):  # noqa: ARG002
-        if fullname in _DISTUTILS_PATCH and self.fullname is None:
+        # Guard against race conditions during file rewrite by checking if _DISTUTILS_PATCH is defined.
+        # This can happen when the file is being overwritten while it's being imported by another process.
+        # See https://github.com/pypa/virtualenv/issues/2969 for details.
+        try:
+            distutils_patch = _DISTUTILS_PATCH
+        except NameError:
+            return None
+        if fullname in distutils_patch and self.fullname is None:  # noqa: PLR1702
             # initialize lock[0] lazily
             if len(self.lock) == 0:
-                import threading
+                import threading  # noqa: PLC0415
 
                 lock = threading.Lock()
                 # there is possibility that two threads T1 and T2 are simultaneously running into find_spec,
@@ -64,8 +70,8 @@ class _Finder:
                 # https://docs.python.org/3/faq/library.html#what-kinds-of-global-value-mutation-are-thread-safe
                 self.lock.append(lock)
 
-            from functools import partial
-            from importlib.util import find_spec
+            from functools import partial  # noqa: PLC0415
+            from importlib.util import find_spec  # noqa: PLC0415
 
             with self.lock[0]:
                 self.fullname = fullname
@@ -78,8 +84,10 @@ class _Finder:
                         old = getattr(spec.loader, func_name)
                         func = self.exec_module if is_new_api else self.load_module
                         if old is not func:
-                            with suppress(AttributeError):  # C-Extension loaders are r/o such as zipimporter with <3.7
+                            try:  # noqa: SIM105
                                 setattr(spec.loader, func_name, partial(func, old))
+                            except AttributeError:
+                                pass  # C-Extension loaders are r/o such as zipimporter with <3.7
                         return spec
                 finally:
                     self.fullname = None
@@ -88,14 +96,26 @@ class _Finder:
     @staticmethod
     def exec_module(old, module):
         old(module)
-        if module.__name__ in _DISTUTILS_PATCH:
-            patch_dist(module)
+        try:
+            distutils_patch = _DISTUTILS_PATCH
+        except NameError:
+            return
+        if module.__name__ in distutils_patch:
+            # patch_dist or its dependencies may not be defined during file rewrite
+            with contextlib.suppress(NameError):
+                patch_dist(module)
 
     @staticmethod
     def load_module(old, name):
         module = old(name)
-        if module.__name__ in _DISTUTILS_PATCH:
-            patch_dist(module)
+        try:
+            distutils_patch = _DISTUTILS_PATCH
+        except NameError:
+            return module
+        if module.__name__ in distutils_patch:
+            # patch_dist or its dependencies may not be defined during file rewrite
+            with contextlib.suppress(NameError):
+                patch_dist(module)
         return module
 
 
