@@ -12,11 +12,9 @@ from typing import ClassVar
 import pytest
 
 from virtualenv.app_data import AppDataDiskFolder
-from virtualenv.cache import FileCache
 from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.info import IS_GRAALPY, IS_PYPY, IS_WIN, fs_supports_symlink
 from virtualenv.report import LOGGER
-from virtualenv.run.plugin.creators import CreatorSelector
 
 
 def pytest_addoption(parser):
@@ -126,10 +124,9 @@ def _check_cwd_not_changed_by_test():
 
 @pytest.fixture(autouse=True)
 def _ensure_py_info_cache_empty(session_app_data):
-    cache = FileCache(session_app_data.py_info, session_app_data.py_info_clear)
-    PythonInfo.clear_cache(cache)
+    PythonInfo.clear_cache(session_app_data)
     yield
-    PythonInfo.clear_cache(cache)
+    PythonInfo.clear_cache(session_app_data)
 
 
 @contextmanager
@@ -201,9 +198,7 @@ COVERAGE_RUN = os.environ.get(str(COV_ENV_VAR))
 
 @pytest.fixture(autouse=True)
 def coverage_env(monkeypatch, link, request):
-    """
-    Enable coverage report collection on the created virtual environments by injecting the coverage project
-    """
+    """Enable coverage report collection on the created virtual environments by injecting the coverage project"""
     if COVERAGE_RUN and "_no_coverage" not in request.fixturenames:
         # we inject right after creation, we cannot collect coverage on site.py - used for helper scripts, such as debug
         from virtualenv import run  # noqa: PLC0415
@@ -311,8 +306,7 @@ def special_name_dir(tmp_path, special_char_name):
 
 @pytest.fixture(scope="session")
 def current_creators(session_app_data):
-    cache = FileCache(session_app_data.py_info, session_app_data.py_info_clear)
-    return CreatorSelector.for_interpreter(PythonInfo.current_system(session_app_data, cache))
+    return PythonInfo.current_system(session_app_data).creators()
 
 
 @pytest.fixture(scope="session")
@@ -330,10 +324,7 @@ def session_app_data(tmp_path_factory):
 
 @contextmanager
 def change_env_var(key, value):
-    """Temporarily change an environment variable.
-    :param key: the key of the env var
-    :param value: the value of the env var
-    """
+    """Temporarily change an environment variable. :param key: the key of the env var :param value: the value of the env var"""
     already_set = key in os.environ
     prev_value = os.environ.get(key)
     os.environ[key] = value
@@ -360,8 +351,7 @@ def for_py_version():
 
 @pytest.fixture
 def _skip_if_test_in_system(session_app_data):
-    cache = FileCache(session_app_data.py_info, session_app_data.py_info_clear)
-    current = PythonInfo.current(session_app_data, cache)
+    current = PythonInfo.current(session_app_data)
     if current.system_executable is not None:
         pytest.skip("test not valid if run under system")
 
