@@ -11,7 +11,6 @@ from uuid import uuid4
 
 import pytest
 
-from tests.unit.discovery.util import MockAppData, MockCache
 from virtualenv.discovery.builtin import Builtin, LazyPathDump, get_interpreter, get_paths
 from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.info import IS_WIN, fs_supports_symlink
@@ -20,10 +19,9 @@ from virtualenv.info import IS_WIN, fs_supports_symlink
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink not supported")
 @pytest.mark.parametrize("case", ["mixed", "lower", "upper"])
 @pytest.mark.parametrize("specificity", ["more", "less", "none"])
-def test_discovery_via_path(monkeypatch, case, specificity, tmp_path, caplog):
+def test_discovery_via_path(monkeypatch, case, specificity, tmp_path, caplog, session_app_data):  # noqa: PLR0913
     caplog.set_level(logging.DEBUG)
-    app_data, cache = MockAppData(), MockCache()
-    current = PythonInfo.current_system(app_data, cache)
+    current = PythonInfo.current_system(session_app_data)
     name = "somethingVeryCryptic"
     threaded = "t" if current.free_threaded else ""
     if case == "lower":
@@ -53,39 +51,36 @@ def test_discovery_via_path(monkeypatch, case, specificity, tmp_path, caplog):
         (target / pyvenv_cfg.name).write_bytes(pyvenv_cfg.read_bytes())
     new_path = os.pathsep.join([str(target), *os.environ.get("PATH", "").split(os.pathsep)])
     monkeypatch.setenv("PATH", new_path)
-    interpreter = get_interpreter(core, [], app_data, cache)
+    interpreter = get_interpreter(core, [])
 
     assert interpreter is not None
 
 
 def test_discovery_via_path_not_found(tmp_path, monkeypatch):
     monkeypatch.setenv("PATH", str(tmp_path))
-    app_data, cache = MockAppData(), MockCache()
-    interpreter = get_interpreter(uuid4().hex, [], app_data, cache)
+    interpreter = get_interpreter(uuid4().hex, [])
     assert interpreter is None
 
 
 def test_discovery_via_path_in_nonbrowseable_directory(tmp_path, monkeypatch):
     bad_perm = tmp_path / "bad_perm"
     bad_perm.mkdir(mode=0o000)
-    app_data, cache = MockAppData(), MockCache()
     # path entry is unreadable
     monkeypatch.setenv("PATH", str(bad_perm))
-    interpreter = get_interpreter(uuid4().hex, [], app_data, cache)
+    interpreter = get_interpreter(uuid4().hex, [])
     assert interpreter is None
     # path entry parent is unreadable
     monkeypatch.setenv("PATH", str(bad_perm / "bin"))
-    interpreter = get_interpreter(uuid4().hex, [], app_data, cache)
+    interpreter = get_interpreter(uuid4().hex, [])
     assert interpreter is None
 
 
-def test_relative_path(monkeypatch):
-    app_data, cache = MockAppData(), MockCache()
-    sys_executable = Path(PythonInfo.current_system(app_data=app_data, cache=cache).system_executable)
+def test_relative_path(session_app_data, monkeypatch):
+    sys_executable = Path(PythonInfo.current_system(app_data=session_app_data).system_executable)
     cwd = sys_executable.parents[1]
     monkeypatch.chdir(str(cwd))
     relative = str(sys_executable.relative_to(cwd))
-    result = get_interpreter(relative, [], app_data, cache)
+    result = get_interpreter(relative, [], session_app_data)
     assert result is not None
 
 
@@ -100,14 +95,13 @@ def test_uv_python(monkeypatch, tmp_path_factory, mocker):
     with patch("virtualenv.discovery.builtin.PathPythonInfo.from_exe") as mock_from_exe, monkeypatch.context() as m:
         m.setenv("UV_PYTHON_INSTALL_DIR", str(uv_python_install_dir))
 
-        app_data, cache = MockAppData(), MockCache()
-        get_interpreter("python", [], app_data, cache)
+        get_interpreter("python", [])
         mock_from_exe.assert_not_called()
 
         bin_path = uv_python_install_dir.joinpath("some-py-impl", "bin")
         bin_path.mkdir(parents=True)
         bin_path.joinpath("python").touch()
-        get_interpreter("python", [], app_data, cache)
+        get_interpreter("python", [])
         mock_from_exe.assert_called_once()
         assert mock_from_exe.call_args[0][0] == str(bin_path / "python")
 
@@ -126,14 +120,13 @@ def test_uv_python(monkeypatch, tmp_path_factory, mocker):
     with patch("virtualenv.discovery.builtin.PathPythonInfo.from_exe") as mock_from_exe, monkeypatch.context() as m:
         m.setenv("XDG_DATA_HOME", str(xdg_data_home))
 
-        app_data, cache = MockAppData(), MockCache()
-        get_interpreter("python", [], app_data, cache)
+        get_interpreter("python", [])
         mock_from_exe.assert_not_called()
 
         bin_path = xdg_data_home.joinpath("uv", "python", "some-py-impl", "bin")
         bin_path.mkdir(parents=True)
         bin_path.joinpath("python").touch()
-        get_interpreter("python", [], app_data, cache)
+        get_interpreter("python", [])
         mock_from_exe.assert_called_once()
         assert mock_from_exe.call_args[0][0] == str(bin_path / "python")
 
@@ -142,24 +135,21 @@ def test_uv_python(monkeypatch, tmp_path_factory, mocker):
     with patch("virtualenv.discovery.builtin.PathPythonInfo.from_exe") as mock_from_exe, monkeypatch.context() as m:
         m.setattr("virtualenv.discovery.builtin.user_data_path", lambda x: user_data_path / x)
 
-        app_data, cache = MockAppData(), MockCache()
-        get_interpreter("python", [], app_data, cache)
+        get_interpreter("python", [])
         mock_from_exe.assert_not_called()
 
         bin_path = user_data_path.joinpath("uv", "python", "some-py-impl", "bin")
         bin_path.mkdir(parents=True)
         bin_path.joinpath("python").touch()
-        get_interpreter("python", [], app_data, cache)
+        get_interpreter("python", [])
         mock_from_exe.assert_called_once()
         assert mock_from_exe.call_args[0][0] == str(bin_path / "python")
 
 
-def test_discovery_fallback_fail(caplog):
+def test_discovery_fallback_fail(session_app_data, caplog):
     caplog.set_level(logging.DEBUG)
-    app_data, cache = MockAppData(), MockCache()
     builtin = Builtin(
-        Namespace(app_data=app_data, try_first_with=[], python=["magic-one", "magic-two"], env=os.environ),
-        cache,
+        Namespace(app_data=session_app_data, try_first_with=[], python=["magic-one", "magic-two"], env=os.environ),
     )
 
     result = builtin.run()
@@ -168,12 +158,10 @@ def test_discovery_fallback_fail(caplog):
     assert "accepted" not in caplog.text
 
 
-def test_discovery_fallback_ok(caplog):
+def test_discovery_fallback_ok(session_app_data, caplog):
     caplog.set_level(logging.DEBUG)
-    app_data, cache = MockAppData(), MockCache()
     builtin = Builtin(
-        Namespace(app_data=app_data, try_first_with=[], python=["magic-one", sys.executable], env=os.environ),
-        cache,
+        Namespace(app_data=session_app_data, try_first_with=[], python=["magic-one", sys.executable], env=os.environ),
     )
 
     result = builtin.run()
@@ -192,12 +180,10 @@ def mock_get_interpreter(mocker):
 
 
 @pytest.mark.usefixtures("mock_get_interpreter")
-def test_returns_first_python_specified_when_only_env_var_one_is_specified(mocker, monkeypatch):
+def test_returns_first_python_specified_when_only_env_var_one_is_specified(mocker, monkeypatch, session_app_data):
     monkeypatch.setenv("VIRTUALENV_PYTHON", "python_from_env_var")
-    app_data, cache = MockAppData(), MockCache()
     builtin = Builtin(
-        Namespace(app_data=app_data, try_first_with=[], python=["python_from_env_var"], env=os.environ),
-        cache,
+        Namespace(app_data=session_app_data, try_first_with=[], python=["python_from_env_var"], env=os.environ),
     )
 
     result = builtin.run()
@@ -206,17 +192,17 @@ def test_returns_first_python_specified_when_only_env_var_one_is_specified(mocke
 
 
 @pytest.mark.usefixtures("mock_get_interpreter")
-def test_returns_second_python_specified_when_more_than_one_is_specified_and_env_var_is_specified(mocker, monkeypatch):
+def test_returns_second_python_specified_when_more_than_one_is_specified_and_env_var_is_specified(
+    mocker, monkeypatch, session_app_data
+):
     monkeypatch.setenv("VIRTUALENV_PYTHON", "python_from_env_var")
-    app_data, cache = MockAppData(), MockCache()
     builtin = Builtin(
         Namespace(
-            app_data=app_data,
+            app_data=session_app_data,
             try_first_with=[],
             python=["python_from_env_var", "python_from_cli"],
             env=os.environ,
         ),
-        cache,
     )
 
     result = builtin.run()
@@ -224,7 +210,7 @@ def test_returns_second_python_specified_when_more_than_one_is_specified_and_env
     assert result == mocker.sentinel.python_from_cli
 
 
-def test_discovery_absolute_path_with_try_first(tmp_path):
+def test_discovery_absolute_path_with_try_first(tmp_path, session_app_data):
     good_env = tmp_path / "good"
     bad_env = tmp_path / "bad"
 
@@ -240,12 +226,10 @@ def test_discovery_absolute_path_with_try_first(tmp_path):
 
     # The spec is an absolute path, this should be a hard requirement.
     # The --try-first-with option should be rejected as it does not match the spec.
-    app_data, cache = MockAppData(), MockCache()
     interpreter = get_interpreter(
         str(good_exe),
         try_first_with=[str(bad_exe)],
-        app_data=app_data,
-        cache=cache,
+        app_data=session_app_data,
     )
 
     assert interpreter is not None
@@ -256,15 +240,12 @@ def test_discovery_via_path_with_file(tmp_path, monkeypatch):
     a_file = tmp_path / "a_file"
     a_file.touch()
     monkeypatch.setenv("PATH", str(a_file))
-    app_data, cache = MockAppData(), MockCache()
-    interpreter = get_interpreter(uuid4().hex, [], app_data, cache)
+    interpreter = get_interpreter(uuid4().hex, [])
     assert interpreter is None
 
 
 def test_absolute_path_does_not_exist(tmp_path):
-    """
-    Test that virtualenv does not fail when an absolute path that does not exist is provided.
-    """
+    """Test that virtualenv does not fail when an absolute path that does not exist is provided."""
     # Create a command that uses an absolute path that does not exist
     # and a valid python executable.
     command = [
@@ -292,9 +273,7 @@ def test_absolute_path_does_not_exist(tmp_path):
 
 
 def test_absolute_path_does_not_exist_fails(tmp_path):
-    """
-    Test that virtualenv fails when a single absolute path that does not exist is provided.
-    """
+    """Test that virtualenv fails when a single absolute path that does not exist is provided."""
     # Create a command that uses an absolute path that does not exist
     command = [
         sys.executable,
@@ -337,14 +316,68 @@ def test_lazy_path_dump_debug(monkeypatch, tmp_path):
 
 
 @pytest.mark.usefixtures("mock_get_interpreter")
-def test_returns_first_python_specified_when_no_env_var_is_specified(mocker, monkeypatch):
+def test_returns_first_python_specified_when_no_env_var_is_specified(mocker, monkeypatch, session_app_data):
     monkeypatch.delenv("VIRTUALENV_PYTHON", raising=False)
-    app_data, cache = MockAppData(), MockCache()
     builtin = Builtin(
-        Namespace(app_data=app_data, try_first_with=[], python=["python_from_cli"], env=os.environ),
-        cache,
+        Namespace(app_data=session_app_data, try_first_with=[], python=["python_from_cli"], env=os.environ),
     )
 
     result = builtin.run()
 
     assert result == mocker.sentinel.python_from_cli
+
+
+def test_discovery_via_version_specifier(session_app_data):
+    """Test that version specifiers like >=3.11 work correctly."""
+    current = PythonInfo.current_system(session_app_data)
+    major, minor = current.version_info.major, current.version_info.minor
+
+    # Test with >= specifier that should match current Python
+    spec = f">={major}.{minor}"
+    interpreter = get_interpreter(spec, [], session_app_data)
+    assert interpreter is not None
+    assert interpreter.version_info.major == major
+    assert interpreter.version_info.minor >= minor
+
+    # Test with compound specifier
+    spec = f">={major}.{minor},<{major}.{minor + 10}"
+    interpreter = get_interpreter(spec, [], session_app_data)
+    assert interpreter is not None
+    assert interpreter.version_info.major == major
+    assert minor <= interpreter.version_info.minor < minor + 10
+
+    # Test with implementation prefix
+    spec = f"cpython>={major}.{minor}"
+    interpreter = get_interpreter(spec, [], session_app_data)
+    if current.implementation == "CPython":
+        assert interpreter is not None
+        assert interpreter.implementation == "CPython"
+
+
+def test_invalid_discovery_via_env_var(monkeypatch, tmp_path):
+    """When VIRTUALENV_DISCOVERY is set to an unavailable plugin, raise a clear error instead of KeyError."""
+    monkeypatch.setenv("VIRTUALENV_DISCOVERY", "nonexistent_plugin")
+    process = subprocess.run(
+        [sys.executable, "-m", "virtualenv", str(tmp_path / "env")],
+        capture_output=True,
+        text=True,
+        check=False,
+        encoding="utf-8",
+    )
+    assert process.returncode != 0
+    output = process.stdout + process.stderr
+    assert "nonexistent_plugin" in output
+    assert "is not available" in output
+    # Should NOT be a raw KeyError
+    assert "KeyError" not in output
+
+
+def test_invalid_discovery_via_env_var_unit(monkeypatch):
+    """Unit test: get_discover raises RuntimeError with helpful message for unknown discovery method."""
+    from virtualenv.config.cli.parser import VirtualEnvConfigParser  # noqa: PLC0415
+    from virtualenv.run.plugin.discovery import get_discover  # noqa: PLC0415
+
+    monkeypatch.setenv("VIRTUALENV_DISCOVERY", "nonexistent_plugin")
+    parser = VirtualEnvConfigParser()
+    with pytest.raises(RuntimeError, match=r"nonexistent_plugin.*is not available"):
+        get_discover(parser, [])
